# -*- coding: utf-8 -*-
"""
update mesh files

USAGE

    python -m thyrsis.database.update_mesh2 [database.sqlite]

    update mesh files
"""
from builtins import str
import sys
import os
from ..database import sqlite
from ..settings import Settings
from ..database import _execute_statements, node_to_elem, db_elem_to_node

def update_mesh2(db_list, dir_name):
    for db in db_list:
        # fix_print_with_import
        print("adding columns for table mailles in", db)
        conn = sqlite.connect(os.path.join(dir_name, db))
        cur = conn.cursor()
        project_SRID = str(cur.execute("SELECT srid FROM geometry_columns WHERE f_table_name = 'noeuds'").fetchone()[0])
        _execute_statements(cur, 'update_mesh2.sql',project_SRID=project_SRID)

        # fix_print_with_import
        print("updating nodes seepage")
        rows = cur.execute("SELECT OGC_FID, flux_eau, infiltration, surface FROM noeuds ORDER BY OGC_FID").fetchall()
        values = []
        rho = 1000.
        if None in [x[1] for x in rows]:
            # fix_print_with_import
            print("flux_eau unknown, seepage not calculated")
        elif None in [x[2] for x in rows]:
            # fix_print_with_import
            print("infiltration unknown, seepage not calculated")
        else:
            for nid, debit, infiltration, surface in rows:
                values.append((infiltration + debit/surface/rho, nid))
            cur.executemany("UPDATE noeuds SET flux_eau = ? WHERE OGC_FID = ? ", values)
            node_to_elem(cur, values)

        # fix_print_with_import
        print("updating mesh surfaces")
        cur.execute("UPDATE mailles SET surface = ST_Area(GEOMETRY)")

        mailles = cur.execute("SELECT OGC_FID, a, b, c, d FROM mailles ORDER BY OGC_FID").fetchall()
        nmailles = len(mailles)

        columns = ['altitude',
                    'altitude_mur',
                    'infiltration',
                    'epaisseur_aquifere',
                    'epaisseur_zs',
                    'epaisseur_zns',
                    'potentiel_reference',
                    'potentiel',
                    'permeabilite_zns']

        for column in columns:
            # fix_print_with_import
            print("updating", column)
            values = cur.execute("SELECT "+column+", OGC_FID FROM noeuds ORDER BY OGC_FID").fetchall()
            node_to_elem(cur, values)

        columns = ['v_x',
                    'v_y',
                    'v_norme']

        for column in columns:
            # fix_print_with_import
            print("updating", column)
            values = cur.execute("SELECT "+column+", OGC_FID FROM mailles ORDER BY OGC_FID").fetchall()
            db_elem_to_node(cur, column, values)

        conn.commit()
        conn.close()


if __name__ == "__main__":
    if len(sys.argv) == 2 and sys.argv[1] in ["-h","--help"]:
        help(sys.modules[__name__])
        exit(0)

    if len(sys.argv) == 2 and sys.argv[1][-7:] == '.sqlite':
        db_list = [sys.argv[1]]
        dir_name = "."
        # fix_print_with_import
        print("upgrading", sys.argv[1], "database")
    else:
        mesh_dir = str(Settings().value("General", "defaultMeshDir"))
        db_list = sorted(os.listdir(mesh_dir))
        dir_name = mesh_dir
        # fix_print_with_import
        print("upgrading", mesh_dir, "directory")
